@@ -9,7 +9,7 @@ import platform
 
 _BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
-def _get_filename():
+def _get_executable():
     path = os.path.join(_BASE_DIR, 'chromedriver_')
 
     sys = platform.system()
@@ -18,16 +18,15 @@ def _get_filename():
         path += 'win32.exe'
     else:
         if sys == 'Darwin':
-            path += 'mac'
+            path += 'mac_arm64' if arch.startswith('arm') else 'mac64'
         elif sys == 'Linux':
-            path += 'linux'
+            path += 'linux64'
         else:
             raise Exception('OS not supported')
 
-        path += '64' if arch.endswith('64') else '32'
         if not os.path.exists(path):
             raise FileNotFoundError('ChromeDriver for {}({}) '
                     'is not found.'.format(sys, arch))
     return path
 
-chromedriver_path = _get_filename()
+chromedriver_path = _get_executable()
